@@ -1,7 +1,4 @@
-var allDescriptors=[{"dependencies":[],"name":"platform","scripts":[]},{"dependencies":["platform"],"name":"toolbox_bootstrap","scripts":[]}];var applicationDescriptor;var _loadedScripts={};function loadResource(url)
-{var xhr=new XMLHttpRequest();xhr.open("GET",url,false);try{xhr.send(null);}catch(e){console.error(url+" -> "+new Error().stack);throw e;}
-return xhr.status<400?xhr.responseText:"";}
-function loadResourcePromise(url)
+var allDescriptors=[{"dependencies":[],"name":"platform","scripts":[]},{"dependencies":["platform"],"name":"toolbox_bootstrap","scripts":[]}];var applicationDescriptor;var _loadedScripts={};for(var k of[]);function loadResourcePromise(url)
 {return new Promise(load);function load(fulfill,reject)
 {var xhr=new XMLHttpRequest();xhr.open("GET",url,true);xhr.onreadystatechange=onreadystatechange;function onreadystatechange(e)
 {if(xhr.readyState!==4)
@@ -19,8 +16,8 @@ var normalizedPath=normalizedSegments.join("/");if(normalizedPath[normalizedPath
 return normalizedPath;if(path[0]==="/"&&normalizedPath)
 normalizedPath="/"+normalizedPath;if((path[path.length-1]==="/")||(segments[segments.length-1]===".")||(segments[segments.length-1]===".."))
 normalizedPath=normalizedPath+"/";return normalizedPath;}
-function loadScriptsPromise(scriptNames)
-{var promises=[];var urls=[];var sources=new Array(scriptNames.length);var scriptToEval=0;for(var i=0;i<scriptNames.length;++i){var scriptName=scriptNames[i];var sourceURL=self._importScriptPathPrefix+scriptName;var schemaIndex=sourceURL.indexOf("://")+3;sourceURL=sourceURL.substring(0,schemaIndex)+normalizePath(sourceURL.substring(schemaIndex));if(_loadedScripts[sourceURL])
+function loadScriptsPromise(scriptNames,base)
+{var promises=[];var urls=[];var sources=new Array(scriptNames.length);var scriptToEval=0;for(var i=0;i<scriptNames.length;++i){var scriptName=scriptNames[i];var sourceURL=(base||self._importScriptPathPrefix)+scriptName;var schemaIndex=sourceURL.indexOf("://")+3;sourceURL=sourceURL.substring(0,schemaIndex)+normalizePath(sourceURL.substring(schemaIndex));if(_loadedScripts[sourceURL])
 continue;urls.push(sourceURL);promises.push(loadResourcePromise(sourceURL).then(scriptSourceLoaded.bind(null,i),scriptSourceLoaded.bind(null,i,undefined)));}
 return Promise.all(promises).then(undefined);function scriptSourceLoaded(scriptNumber,scriptSource)
 {sources[scriptNumber]=scriptSource||"";while(typeof sources[scriptToEval]!=="undefined"){evaluateScript(urls[scriptToEval],sources[scriptToEval]);++scriptToEval;}}
@@ -30,19 +27,9 @@ self.eval(scriptSource+"\n//# sourceURL="+sourceURL);}}
 (function(){var baseUrl=self.location?self.location.origin+self.location.pathname:"";self._importScriptPathPrefix=baseUrl.substring(0,baseUrl.lastIndexOf("/")+1);})();function Runtime(descriptors,coreModuleNames)
 {this._modules=[];this._modulesMap={};this._extensions=[];this._cachedTypeClasses={};this._descriptorsMap={};for(var i=0;i<descriptors.length;++i)
 this._registerModule(descriptors[i]);if(coreModuleNames)
-this._loadAutoStartModules(coreModuleNames).catch(Runtime._reportError);}
+this._loadAutoStartModules(coreModuleNames);}
 Runtime._queryParamsObject={__proto__:null};Runtime.cachedResources={__proto__:null};Runtime.isReleaseMode=function()
 {return!!allDescriptors.length;}
-Runtime.startSharedWorker=function(moduleName,workerName)
-{if(Runtime.isReleaseMode())
-return new SharedWorker(moduleName+"_module.js",workerName);var content=loadResource(moduleName+"/module.json");if(!content)
-throw new Error("Worker is not defined: "+moduleName+" "+new Error().stack);var scripts=JSON.parse(content)["scripts"];if(scripts.length!==1)
-throw Error("Runtime.startSharedWorker supports modules with only one script!");return new SharedWorker(moduleName+"/"+scripts[0],workerName);}
-Runtime.startWorker=function(moduleName)
-{if(Runtime.isReleaseMode())
-return new Worker(moduleName+"_module.js");var content=loadResource(moduleName+"/module.json");if(!content)
-throw new Error("Worker is not defined: "+moduleName+" "+new Error().stack);var message=[];var scripts=JSON.parse(content)["scripts"];for(var i=0;i<scripts.length;++i){var url=self._importScriptPathPrefix+moduleName+"/"+scripts[i];var parts=url.split("://");url=parts.length===1?url:parts[0]+"://"+normalizePath(parts[1]);message.push({source:loadResource(moduleName+"/"+scripts[i]),url:url});}
-var loader=function(){self.onmessage=function(event){self.onmessage=null;var scripts=event.data;for(var i=0;i<scripts.length;++i){var source=scripts[i]["source"];self.eval(source+"\n//# sourceURL="+scripts[i]["url"]);}};};var blob=new Blob(["("+loader.toString()+")()\n//# sourceURL="+moduleName],{type:"text/javascript"});var workerURL=window.URL.createObjectURL(blob);try{var worker=new Worker(workerURL);worker.postMessage(message);return worker;}finally{window.URL.revokeObjectURL(workerURL);}}
 Runtime.startApplication=function(appName)
 {console.timeStamp("Runtime.startApplication");var allDescriptorsByName={};for(var i=0;Runtime.isReleaseMode()&&i<allDescriptors.length;++i){var d=allDescriptors[i];allDescriptorsByName[d["name"]]=d;}
 var applicationPromise;if(applicationDescriptor)
@@ -53,11 +40,15 @@ continue;var name=descriptor["name"];var moduleJSON=allDescriptorsByName[name];i
 moduleJSONPromises.push(Promise.resolve(moduleJSON));else
 moduleJSONPromises.push(loadResourcePromise(name+"/module.json").then(JSON.parse.bind(JSON)));if(descriptor["type"]==="autostart")
 coreModuleNames.push(name);}
-Promise.all(moduleJSONPromises).then(instantiateRuntime).catch(Runtime._reportError);function instantiateRuntime(moduleDescriptors)
-{for(var i=0;!Runtime.isReleaseMode()&&i<moduleDescriptors.length;++i)
-moduleDescriptors[i]["name"]=configuration[i]["name"];self.runtime=new Runtime(moduleDescriptors,coreModuleNames);}}}
+Promise.all(moduleJSONPromises).then(instantiateRuntime);function instantiateRuntime(moduleDescriptors)
+{for(var i=0;!Runtime.isReleaseMode()&&i<moduleDescriptors.length;++i){moduleDescriptors[i]["name"]=configuration[i]["name"];moduleDescriptors[i]["condition"]=configuration[i]["condition"];}
+self.runtime=new Runtime(moduleDescriptors,coreModuleNames);}}}
 Runtime.queryParam=function(name)
 {return Runtime._queryParamsObject[name]||null;}
+Runtime.constructQueryParams=function(banned)
+{var params=[];for(var key in Runtime._queryParamsObject){if(!key||banned.indexOf(key)!==-1)
+continue;params.push(key+"="+Runtime._queryParamsObject[key]);}
+return params.length?"?"+params.join("&"):"";}
 Runtime._experimentsSetting=function()
 {try{return(JSON.parse(self.localStorage&&self.localStorage["experiments"]?self.localStorage["experiments"]:"{}"));}catch(e){console.error("Failed to parse localStorage['experiments']");return{};}}
 Runtime._some=function(promises)
@@ -70,12 +61,9 @@ function handler(index,e)
 {wasRejected[index]=true;console.error(e.stack);}}
 Runtime._console=console;Runtime._originalAssert=console.assert;Runtime._assert=function(value,message)
 {if(value)
-return;Runtime._originalAssert.call(Runtime._console,value,message);}
-Runtime._reportError=function(e)
-{if(e instanceof Error)
-console.error(e.stack);else
-console.error(e);}
-Runtime.prototype={_registerModule:function(descriptor)
+return;Runtime._originalAssert.call(Runtime._console,value,message+" "+new Error().stack);}
+Runtime.prototype={useTestBase:function()
+{Runtime._remoteBase="http://localhost:8000/inspector-sources/";},_registerModule:function(descriptor)
 {var module=new Runtime.Module(this,descriptor);this._modules.push(module);this._modulesMap[descriptor["name"]]=module;},loadModulePromise:function(moduleName)
 {return this._modulesMap[moduleName]._loadPromise();},_loadAutoStartModules:function(moduleNames)
 {var promises=[];for(var i=0;i<moduleNames.length;++i){if(Runtime.isReleaseMode())
@@ -95,8 +83,7 @@ return true;return this._checkExtensionApplicability(extension,currentContextTyp
 {return currentContextTypes.has(targetType);}},extensions:function(type,context)
 {return this._extensions.filter(filter).sort(orderComparator);function filter(extension)
 {if(extension._type!==type&&extension._typeClass()!==type)
-return false;var activatorExperiment=extension.descriptor()["experiment"];if(activatorExperiment&&!Runtime.experiments.isEnabled(activatorExperiment))
-return false;activatorExperiment=extension._module._descriptor["experiment"];if(activatorExperiment&&!Runtime.experiments.isEnabled(activatorExperiment))
+return false;if(!extension.enabled())
 return false;return!context||extension.isApplicable(context);}
 function orderComparator(extension1,extension2)
 {var order1=extension1.descriptor()["order"]||0;var order2=extension2.descriptor()["order"]||0;return order1-order2;}},extension:function(type,context)
@@ -110,23 +97,35 @@ object=object[path[i]];if(object)
 this._cachedTypeClasses[typeName]=(object);}
 return this._cachedTypeClasses[typeName]||null;}}
 Runtime.ModuleDescriptor=function()
-{this.name;this.extensions;this.dependencies;this.scripts;}
+{this.name;this.extensions;this.dependencies;this.scripts;this.remote;}
 Runtime.ExtensionDescriptor=function()
 {this.type;this.className;this.contextTypes;}
 Runtime.Module=function(manager,descriptor)
 {this._manager=manager;this._descriptor=descriptor;this._name=descriptor.name;this._instanceMap={};var extensions=(descriptor.extensions);for(var i=0;extensions&&i<extensions.length;++i)
 this._manager._extensions.push(new Runtime.Extension(this,extensions[i]));this._loaded=false;}
 Runtime.Module.prototype={name:function()
-{return this._name;},_loadPromise:function()
+{return this._name;},enabled:function()
+{var activatorExperiment=this._descriptor["experiment"];if(activatorExperiment&&!Runtime.experiments.isEnabled(activatorExperiment))
+return false;var condition=this._descriptor["condition"];if(condition&&!Runtime.queryParam(condition))
+return false;return true;},resource:function(name)
+{var fullName=this._name+"/"+name;var content=Runtime.cachedResources[fullName];if(!content)
+throw new Error(fullName+" not preloaded. Check module.json");return content;},_loadPromise:function()
 {if(this._loaded)
-return Promise.resolve();if(this._pendingLoadPromise)
+return Promise.resolve();if(!this.enabled())
+return Promise.reject(new Error("Module "+this._name+" is not enabled"));if(this._pendingLoadPromise)
 return this._pendingLoadPromise;var dependencies=this._descriptor.dependencies;var dependencyPromises=[];for(var i=0;dependencies&&i<dependencies.length;++i)
-dependencyPromises.push(this._manager._modulesMap[dependencies[i]]._loadPromise());this._pendingLoadPromise=Promise.all(dependencyPromises).then(this._loadScripts.bind(this)).then(markAsLoaded.bind(this));return this._pendingLoadPromise;function markAsLoaded()
-{delete this._pendingLoadPromise;this._loaded=true;}},_loadScripts:function()
+dependencyPromises.push(this._manager._modulesMap[dependencies[i]]._loadPromise());this._pendingLoadPromise=Promise.all(dependencyPromises).then(this._loadResources.bind(this)).then(this._loadScripts.bind(this)).then(markAsLoaded.bind(this));return this._pendingLoadPromise;function markAsLoaded()
+{delete this._pendingLoadPromise;this._loaded=true;}},_loadResources:function()
+{var resources=this._descriptor["resources"];if(!resources)
+return Promise.resolve();var promises=[];for(var i=0;i<resources.length;++i){var url=this._modularizeURL(resources[i]);promises.push(loadResourcePromise(url).then(cacheResource.bind(this,url),cacheResource.bind(this,url,undefined)));}
+return Promise.all(promises).then(undefined);function cacheResource(path,content)
+{if(!content){console.error("Failed to load resource: "+path);return;}
+var sourceURL=window.location.href;if(window.location.search)
+sourceURL=sourceURL.replace(window.location.search,"");sourceURL=sourceURL.substring(0,sourceURL.lastIndexOf("/")+1)+path;Runtime.cachedResources[path]=content+"\n/*# sourceURL="+sourceURL+" */";}},_loadScripts:function()
 {if(!this._descriptor.scripts)
-return Promise.resolve(undefined);if(Runtime.isReleaseMode())
-return loadScriptsPromise([this._name+"_module.js"]);return loadScriptsPromise(this._descriptor.scripts.map(modularizeURL,this)).catch(Runtime._reportError);function modularizeURL(scriptName)
-{return this._name+"/"+scriptName;}},_instance:function(className)
+return Promise.resolve();if(Runtime.isReleaseMode()){var useRemote=this._descriptor.remote&&Runtime.experiments.isEnabled("remoteModules");var base=useRemote&&Runtime._remoteBase||undefined;return loadScriptsPromise([this._name+"_module.js"],base);}
+return loadScriptsPromise(this._descriptor.scripts.map(this._modularizeURL,this));},_modularizeURL:function(resourceName)
+{return normalizePath(this._name+"/"+resourceName);},_instance:function(className)
 {if(className in this._instanceMap)
 return this._instanceMap[className];var constructorFunction=window.eval(className);if(!(constructorFunction instanceof Function)){this._instanceMap[className]=null;return null;}
 var instance=new constructorFunction();this._instanceMap[className]=instance;return instance;}}
@@ -134,7 +133,10 @@ Runtime.Extension=function(module,descriptor)
 {this._module=module;this._descriptor=descriptor;this._type=descriptor.type;this._hasTypeClass=this._type.charAt(0)==="@";this._className=descriptor.className||null;}
 Runtime.Extension.prototype={descriptor:function()
 {return this._descriptor;},module:function()
-{return this._module;},_typeClass:function()
+{return this._module;},enabled:function()
+{var activatorExperiment=this.descriptor()["experiment"];if(activatorExperiment&&!Runtime.experiments.isEnabled(activatorExperiment))
+return false;var condition=this.descriptor()["condition"];if(condition&&!Runtime.queryParam(condition))
+return false;return this._module.enabled();},_typeClass:function()
 {if(!this._hasTypeClass)
 return null;return this._module._manager._resolve(this._type.substring(1));},isApplicable:function(context)
 {return this._module._manager.isExtensionApplicableToContext(this,context);},instancePromise:function()
@@ -142,7 +144,8 @@ return null;return this._module._manager._resolve(this._type.substring(1));},isA
 return Promise.reject(new Error("No class name in extension"));var className=this._className;if(this._instance)
 return Promise.resolve(this._instance);return this._module._loadPromise().then(constructInstance.bind(this));function constructInstance()
 {var result=this._module._instance(className);if(!result)
-return Promise.reject("Could not instantiate: "+className);return result;}}}
+return Promise.reject("Could not instantiate: "+className);return result;}},title:function(platform)
+{return this._descriptor["title-"+platform]||this._descriptor["title"];}}
 Runtime.ExperimentsSupport=function()
 {this._supportEnabled=Runtime.queryParam("experiments")!==null;this._experiments=[];this._experimentNames={};this._enabledTransiently={};}
 Runtime.ExperimentsSupport.prototype={allConfigurableExperiments:function()
@@ -170,22 +173,8 @@ Runtime.Experiment.prototype={isEnabled:function()
 {this._experiments.setEnabled(this.name,enabled);}}
 {(function parseQueryParameters()
 {var queryParams=location.search;if(!queryParams)
-return;var params=queryParams.substring(1).split("&");for(var i=0;i<params.length;++i){var pair=params[i].split("=");Runtime._queryParamsObject[pair[0]]=pair[1];}
-var settingsParam=Runtime.queryParam("settings");if(settingsParam){try{var settings=JSON.parse(window.decodeURI(settingsParam));for(var key in settings)
-window.localStorage[key]=settings[key];}catch(e){}}})();}
-Runtime.experiments=new Runtime.ExperimentsSupport();var runtime;Promise.rejectWithError=function(error)
-{return Promise.reject(new Error(error));}
-Promise.prototype.thenOrCatch=function(callback)
-{return this.then(callback,reject.bind(this));function reject(e)
-{this._reportError(e);callback(undefined);}}
-Promise.prototype.done=function()
-{this.catchAndReport();}
-Promise.prototype.catchAndReport=function()
-{return this.catch(this._reportError.bind(this));}
-Promise.prototype._reportError=function(e)
-{if(e instanceof Error)
-console.error(e.stack);else
-console.error(e);};console=console;console.__originalAssert=console.assert;console.assert=function(value,message)
+return;var params=queryParams.substring(1).split("&");for(var i=0;i<params.length;++i){var pair=params[i].split("=");var name=pair.shift();Runtime._queryParamsObject[name]=pair.join("=");}})();}
+Runtime.experiments=new Runtime.ExperimentsSupport();Runtime.experiments.register("remoteModules","Remote Modules",true);Runtime._remoteBase=Runtime.queryParam("remoteBase");var runtime;console=console;console.__originalAssert=console.assert;console.assert=function(value,message)
 {if(value)
 return;console.__originalAssert(value,message);}
 var ArrayLike;Object.isEmpty=function(obj)
@@ -230,8 +219,9 @@ String.prototype.trimEnd=function(maxLength)
 {if(this.length<=maxLength)
 return String(this);return this.substr(0,maxLength-1)+"\u2026";}
 String.prototype.trimURL=function(baseURLDomain)
-{var result=this.replace(/^(https|http|file):\/\//i,"");if(baseURLDomain)
-result=result.replace(new RegExp("^"+baseURLDomain.escapeForRegExp(),"i"),"");return result;}
+{var result=this.replace(/^(https|http|file):\/\//i,"");if(baseURLDomain){if(result.toLowerCase().startsWith(baseURLDomain.toLowerCase()))
+result=result.substr(baseURLDomain.length);}
+return result;}
 String.prototype.toTitleCase=function()
 {return this.substring(0,1).toUpperCase()+this.substring(1);}
 String.prototype.compareTo=function(other)
@@ -247,11 +237,20 @@ String.prototype.startsWith=function(substring)
 {return!this.lastIndexOf(substring,0);}
 String.prototype.endsWith=function(substring)
 {return this.indexOf(substring,this.length-substring.length)!==-1;}
-String.prototype.hashCode=function()
-{var result=0;for(var i=0;i<this.length;++i)
-result=(result*3+this.charCodeAt(i))|0;return result;}
-String.prototype.isDigitAt=function(index)
-{var c=this.charCodeAt(index);return 48<=c&&c<=57;}
+String.hashCode=function(string)
+{if(!string)
+return 0;var result=0;for(var i=0;i<string.length;++i)
+result=(result*3+string.charCodeAt(i))|0;return result;}
+String.isDigitAt=function(string,index)
+{var c=string.charCodeAt(index);return 48<=c&&c<=57;}
+String.prototype.toBase64=function()
+{function encodeBits(b)
+{return b<26?b+65:b<52?b+71:b<62?b-4:b===62?43:b===63?47:65;}
+var encoder=new TextEncoder();var data=encoder.encode(this.toString());var n=data.length;var encoded="";if(n===0)
+return encoded;var shift;var v=0;for(var i=0;i<n;i++){shift=i%3;v|=data[i]<<(16>>>shift&24);if(shift===2){encoded+=String.fromCharCode(encodeBits(v>>>18&63),encodeBits(v>>>12&63),encodeBits(v>>>6&63),encodeBits(v&63));v=0;}}
+if(shift===0)
+encoded+=String.fromCharCode(encodeBits(v>>>18&63),encodeBits(v>>>12&63),61,61);else if(shift===1)
+encoded+=String.fromCharCode(encodeBits(v>>>18&63),encodeBits(v>>>12&63),encodeBits(v>>>6&63),61);return encoded;}
 String.naturalOrderComparator=function(a,b)
 {var chunk=/^\d+|^\D+/;var chunka,chunkb,anum,bnum;while(1){if(a){if(!b)
 return 1;}else{if(b)
@@ -288,7 +287,7 @@ Date.prototype.toConsoleTime=function()
 {function leadZero2(x)
 {return(x>9?"":"0")+x;}
 function leadZero3(x)
-{return(Array(4-x.toString().length)).join('0')+x;}
+{return"0".repeat(3-x.toString().length)+x;}
 return this.getFullYear()+"-"+
 leadZero2(this.getMonth()+1)+"-"+
 leadZero2(this.getDate())+" "+
@@ -375,11 +374,12 @@ String.tokenizeFormatString=function(format,formatters)
 {tokens.push({type:"string",value:str});}
 function addSpecifierToken(specifier,precision,substitutionIndex)
 {tokens.push({type:"specifier",specifier:specifier,precision:precision,substitutionIndex:substitutionIndex});}
-var index=0;for(var precentIndex=format.indexOf("%",index);precentIndex!==-1;precentIndex=format.indexOf("%",index)){addStringToken(format.substring(index,precentIndex));index=precentIndex+1;if(format[index]==="%"){addStringToken("%");++index;continue;}
-if(format.isDigitAt(index)){var number=parseInt(format.substring(index),10);while(format.isDigitAt(index))
+var index=0;for(var precentIndex=format.indexOf("%",index);precentIndex!==-1;precentIndex=format.indexOf("%",index)){if(format.length===index)
+break;addStringToken(format.substring(index,precentIndex));index=precentIndex+1;if(format[index]==="%"){addStringToken("%");++index;continue;}
+if(String.isDigitAt(format,index)){var number=parseInt(format.substring(index),10);while(String.isDigitAt(format,index))
 ++index;if(number>0&&format[index]==="$"){substitutionIndex=(number-1);++index;}}
 var precision=-1;if(format[index]==="."){++index;precision=parseInt(format.substring(index),10);if(isNaN(precision))
-precision=0;while(format.isDigitAt(index))
+precision=0;while(String.isDigitAt(format,index))
 ++index;}
 if(!(format[index]in formatters)){addStringToken(format.substring(precentIndex,index+1));++index;continue;}
 addSpecifierToken(format[index],precision,substitutionIndex);++substitutionIndex;++index;}
@@ -420,32 +420,30 @@ function countRegexMatches(regex,content)
 ++result;text=text.substring(match.index+1);}
 return result;}
 function spacesPadding(spacesCount)
-{return Array(spacesCount).join("\u00a0");}
+{return"\u00a0".repeat(spacesCount);}
 function numberToStringWithSpacesPadding(value,symbolsCount)
 {var numberString=value.toString();var paddingLength=Math.max(0,symbolsCount-numberString.length);return spacesPadding(paddingLength)+numberString;}
 Array.from=function(iterator)
 {var values=[];for(var iteratorValue=iterator.next();!iteratorValue.done;iteratorValue=iterator.next())
 values.push(iteratorValue.value);return values;}
-Set.fromArray=function(array)
-{return new Set(array);}
 Set.prototype.valuesArray=function()
 {return Array.from(this.values());}
-Set.prototype.remove=Set.prototype.delete;Map.prototype.remove=function(key)
+Map.prototype.remove=function(key)
 {var value=this.get(key);this.delete(key);return value;}
 Map.prototype.valuesArray=function()
 {return Array.from(this.values());}
 Map.prototype.keysArray=function()
 {return Array.from(this.keys());}
-var StringMultimap=function()
+var Multimap=function()
 {this._map=new Map();}
-StringMultimap.prototype={set:function(key,value)
+Multimap.prototype={set:function(key,value)
 {var set=this._map.get(key);if(!set){set=new Set();this._map.set(key,set);}
 set.add(value);},get:function(key)
 {var result=this._map.get(key);if(!result)
 result=new Set();return result;},remove:function(key,value)
-{var values=this.get(key);values.remove(value);if(!values.size)
-this._map.remove(key)},removeAll:function(key)
-{this._map.remove(key)},keysArray:function()
+{var values=this.get(key);values.delete(value);if(!values.size)
+this._map.delete(key);},removeAll:function(key)
+{this._map.delete(key);},keysArray:function()
 {return this._map.keysArray();},valuesArray:function()
 {var result=[];var keys=this.keysArray();for(var i=0;i<keys.length;++i)
 result.pushAll(this.get(keys[i]).valuesArray());return result;},clear:function()
@@ -456,7 +454,7 @@ function loadXHR(url)
 {if(xhr.readyState!==XMLHttpRequest.DONE)
 return;if(xhr.status!==200){xhr.onreadystatechange=null;failureCallback(new Error(xhr.status));return;}
 xhr.onreadystatechange=null;successCallback(xhr.responseText);}
-var xhr=new XMLHttpRequest();xhr.open("GET",url,true);xhr.onreadystatechange=onReadyStateChanged;xhr.send(null);}}
+var xhr=new XMLHttpRequest();xhr.withCredentials=false;xhr.open("GET",url,true);xhr.onreadystatechange=onReadyStateChanged;xhr.send(null);}}
 function CallbackBarrier()
 {this._pendingIncomingCallbacksCount=0;}
 CallbackBarrier.prototype={createCallback:function(userCallback)
@@ -469,7 +467,10 @@ this._outgoingCallback();}}
 function suppressUnused(value)
 {}
 self.setImmediate=function(callback)
-{Promise.resolve().then(callback).done();return 0;};Node.prototype.rangeOfWord=function(offset,stopCharacters,stayWithinNode,direction)
+{Promise.resolve().then(callback);return 0;}
+Promise.prototype.spread=function(callback)
+{return this.then(spreadPromise);function spreadPromise(arg)
+{return callback.apply(null,arg);}};Node.prototype.rangeOfWord=function(offset,stopCharacters,stayWithinNode,direction)
 {var startNode;var startOffset=0;var endNode;var endOffset=0;if(!stayWithinNode)
 stayWithinNode=this;if(!direction||direction==="backward"||direction==="both"){var node=this;while(node){if(node===stayWithinNode){if(!startNode)
 startNode=stayWithinNode;break;}
@@ -486,12 +487,8 @@ if(!endNode){endNode=stayWithinNode;endOffset=stayWithinNode.nodeType===Node.TEX
 var result=this.ownerDocument.createRange();result.setStart(startNode,startOffset);result.setEnd(endNode,endOffset);return result;}
 Node.prototype.traverseNextTextNode=function(stayWithin)
 {var node=this.traverseNextNode(stayWithin);if(!node)
-return null;while(node&&node.nodeType!==Node.TEXT_NODE)
+return null;var nonTextTags={"STYLE":1,"SCRIPT":1};while(node&&(node.nodeType!==Node.TEXT_NODE||nonTextTags[node.parentElement.nodeName]))
 node=node.traverseNextNode(stayWithin);return node;}
-Node.prototype.rangeBoundaryForOffset=function(offset)
-{var node=this.traverseNextTextNode(this);while(node&&offset>node.nodeValue.length){offset-=node.nodeValue.length;node=node.traverseNextTextNode(this);}
-if(!node)
-return{container:this,offset:0};return{container:node,offset:offset};}
 Element.prototype.positionAt=function(x,y,relativeTo)
 {var shift={x:0,y:0};if(relativeTo)
 shift=relativeTo.boxInWindow(this.ownerDocument.defaultView);if(typeof x==="number")
@@ -512,8 +509,12 @@ return null;}
 Node.prototype.enclosingNodeOrSelfWithNodeName=function(nodeName)
 {return this.enclosingNodeOrSelfWithNodeNameInArray([nodeName]);}
 Node.prototype.enclosingNodeOrSelfWithClass=function(className,stayWithin)
-{for(var node=this;node&&node!==stayWithin&&node!==this.ownerDocument;node=node.parentNodeOrShadowHost()){if(node.nodeType===Node.ELEMENT_NODE&&node.classList.contains(className))
-return(node);}
+{return this.enclosingNodeOrSelfWithClassList([className],stayWithin);}
+Node.prototype.enclosingNodeOrSelfWithClassList=function(classNames,stayWithin)
+{for(var node=this;node&&node!==stayWithin&&node!==this.ownerDocument;node=node.parentNodeOrShadowHost()){if(node.nodeType===Node.ELEMENT_NODE){var containsAll=true;for(var i=0;i<classNames.length&&containsAll;++i){if(!node.classList.contains(classNames[i]))
+containsAll=false;}
+if(containsAll)
+return(node);}}
 return null;}
 Node.prototype.parentElementOrShadowHost=function()
 {var node=this.parentNode;if(!node)
@@ -522,6 +523,14 @@ return(node);if(node.nodeType===Node.DOCUMENT_FRAGMENT_NODE)
 return(node.host);return null;}
 Node.prototype.parentNodeOrShadowHost=function()
 {return this.parentNode||this.host||null;}
+Node.prototype.getComponentSelection=function()
+{var parent=this.parentNode;while(parent&&parent.nodeType!==Node.DOCUMENT_FRAGMENT_NODE)
+parent=parent.parentNode;return parent instanceof ShadowRoot?parent.getSelection():this.window().getSelection();}
+Node.prototype.isComponentSelectionCollapsed=function()
+{var selection=this.getComponentSelection();return selection&&selection.rangeCount?selection.getRangeAt(0).collapsed:true;}
+Node.prototype.getDeepSelection=function()
+{var activeElement=this.ownerDocument.activeElement;var shadowRoot=null;while(activeElement&&activeElement.shadowRoot){shadowRoot=activeElement.shadowRoot;activeElement=shadowRoot.activeElement;}
+return shadowRoot?shadowRoot.getSelection():this.window().getSelection();}
 Node.prototype.window=function()
 {return this.ownerDocument.defaultView;}
 Element.prototype.query=function(query)
@@ -530,21 +539,28 @@ Element.prototype.removeChildren=function()
 {if(this.firstChild)
 this.textContent="";}
 Element.prototype.isInsertionCaretInside=function()
-{var selection=window.getSelection();if(!selection.rangeCount||!selection.isCollapsed)
+{var selection=this.getComponentSelection();if(!selection.rangeCount||!selection.isCollapsed)
 return false;var selectionRange=selection.getRangeAt(0);return selectionRange.startContainer.isSelfOrDescendant(this);}
-function createElement(tagName)
-{return document.createElement(tagName);}
+function createElement(tagName,customElementType)
+{return document.createElement(tagName,customElementType||"");}
+function createEvent(type,bubbles,cancelable)
+{var event=document.createEvent("Event");event.initEvent(type,bubbles,cancelable);return event;}
 function createTextNode(data)
 {return document.createTextNode(data);}
-Document.prototype.createElementWithClass=function(elementName,className)
-{var element=this.createElement(elementName);if(className)
+Document.prototype.createElementWithClass=function(elementName,className,customElementType)
+{var element=this.createElement(elementName,customElementType||"");if(className)
 element.className=className;return element;}
-function createElementWithClass(elementName,className)
-{return document.createElementWithClass(elementName,className);}
+function createElementWithClass(elementName,className,customElementType)
+{return document.createElementWithClass(elementName,className,customElementType);}
+Document.prototype.createSVGElement=function(childType,className)
+{var element=this.createElementNS("http://www.w3.org/2000/svg",childType);if(className)
+element.setAttribute("class",className);return element;}
+function createSVGElement(childType,className)
+{return document.createSVGElement(childType,className);}
 function createDocumentFragment()
 {return document.createDocumentFragment();}
-Element.prototype.createChild=function(elementName,className)
-{var element=this.ownerDocument.createElementWithClass(elementName,className);this.appendChild(element);return element;}
+Element.prototype.createChild=function(elementName,className,customElementType)
+{var element=this.ownerDocument.createElementWithClass(elementName,className,customElementType);this.appendChild(element);return element;}
 DocumentFragment.prototype.createChild=Element.prototype.createChild;Element.prototype.createTextChild=function(text)
 {var element=this.ownerDocument.createTextNode(text);this.appendChild(element);return element;}
 DocumentFragment.prototype.createTextChild=Element.prototype.createTextChild;Element.prototype.createTextChildren=function(var_args)
@@ -562,6 +578,8 @@ Element.prototype.totalOffset=function()
 Element.prototype.scrollOffset=function()
 {var curLeft=0;var curTop=0;for(var element=this;element;element=element.scrollParent){curLeft+=element.scrollLeft;curTop+=element.scrollTop;}
 return{left:curLeft,top:curTop};}
+Element.prototype.createSVGChild=function(childType,className)
+{var child=this.ownerDocument.createSVGElement(childType,className);this.appendChild(child);return child;}
 function AnchorBox(x,y,width,height)
 {this.x=x||0;this.y=y||0;this.width=width||0;this.height=height||0;}
 AnchorBox.prototype.relativeTo=function(box)
@@ -588,16 +606,18 @@ return"";}});Event.prototype.consume=function(preventDefault)
 this.preventDefault();this.handled=true;}
 Text.prototype.select=function(start,end)
 {start=start||0;end=end||this.textContent.length;if(start<0)
-start=end+start;var selection=this.ownerDocument.defaultView.getSelection();selection.removeAllRanges();var range=this.ownerDocument.createRange();range.setStart(this,start);range.setEnd(this,end);selection.addRange(range);return this;}
+start=end+start;var selection=this.getComponentSelection();selection.removeAllRanges();var range=this.ownerDocument.createRange();range.setStart(this,start);range.setEnd(this,end);selection.addRange(range);return this;}
 Element.prototype.selectionLeftOffset=function()
-{var selection=window.getSelection();if(!selection.containsNode(this,true))
+{var selection=this.getComponentSelection();if(!selection.containsNode(this,true))
 return null;var leftOffset=selection.anchorOffset;var node=selection.anchorNode;while(node!==this){while(node.previousSibling){node=node.previousSibling;leftOffset+=node.textContent.length;}
 node=node.parentNodeOrShadowHost();}
 return leftOffset;}
 Node.prototype.deepTextContent=function()
+{return this.childTextNodes().map(function(node){return node.textContent;}).join("");}
+Node.prototype.childTextNodes=function()
 {var node=this.traverseNextTextNode(this);var result=[];var nonTextTags={"STYLE":1,"SCRIPT":1};while(node){if(!nonTextTags[node.parentElement.nodeName])
-result.push(node.textContent);node=node.traverseNextTextNode(this);}
-return result.join("");}
+result.push(node);node=node.traverseNextTextNode(this);}
+return result;}
 Node.prototype.isAncestor=function(node)
 {if(!node)
 return false;var currentNode=node.parentNodeOrShadowHost();while(currentNode){if(this===currentNode)
@@ -610,20 +630,26 @@ Node.prototype.isSelfOrAncestor=function(node)
 Node.prototype.isSelfOrDescendant=function(node)
 {return!!node&&(node===this||this.isDescendant(node));}
 Node.prototype.traverseNextNode=function(stayWithin)
-{if(this.firstChild)
-return this.firstChild;if(this.shadowRoot)
-return this.shadowRoot;if(stayWithin&&this===stayWithin)
-return null;var node=this.nextSibling;if(node)
-return node;node=this;while(node&&!node.nextSibling&&(!stayWithin||!node.parentNodeOrShadowHost()||node.parentNodeOrShadowHost()!==stayWithin))
-node=node.parentNodeOrShadowHost();if(!node)
-return null;return node.nextSibling;}
+{if(this.shadowRoot)
+return this.shadowRoot;var distributedNodes=this.getDistributedNodes?this.getDistributedNodes():[];if(distributedNodes.length)
+return distributedNodes[0];if(this.firstChild)
+return this.firstChild;var node=this;while(node){if(stayWithin&&node===stayWithin)
+return null;var sibling=nextSibling(node);if(sibling)
+return sibling;node=insertionPoint(node)||node.parentNodeOrShadowHost();}
+function nextSibling(node)
+{var parent=insertionPoint(node);if(!parent)
+return node.nextSibling;var distributedNodes=parent.getDistributedNodes?parent.getDistributedNodes():[];var position=Array.prototype.indexOf.call(distributedNodes,node);if(position+1<distributedNodes.length)
+return distributedNodes[position+1];return null;}
+function insertionPoint(node)
+{var insertionPoints=node.getDestinationInsertionPoints?node.getDestinationInsertionPoints():[];return insertionPoints.length>0?insertionPoints[insertionPoints.length-1]:null;}
+return null;}
 Node.prototype.traversePreviousNode=function(stayWithin)
 {if(stayWithin&&this===stayWithin)
 return null;var node=this.previousSibling;while(node&&node.lastChild)
 node=node.lastChild;if(node)
 return node;return this.parentNodeOrShadowHost();}
 Node.prototype.setTextContentTruncatedIfNeeded=function(text,placeholder)
-{const maxTextContentLength=65535;if(typeof text==="string"&&text.length>maxTextContentLength){this.textContent=typeof placeholder==="string"?placeholder:text.trimEnd(maxTextContentLength);return true;}
+{const maxTextContentLength=10000;if(typeof text==="string"&&text.length>maxTextContentLength){this.textContent=typeof placeholder==="string"?placeholder:text.trimMiddle(maxTextContentLength);return true;}
 this.textContent=text;return false;}
 Event.prototype.deepElementFromPoint=function()
 {var node=this.target;while(node&&node.nodeType!==Node.DOCUMENT_FRAGMENT_NODE&&node.nodeType!==Node.DOCUMENT_NODE)
@@ -633,16 +659,19 @@ node=node.shadowRoot.elementFromPoint(this.pageX,this.pageY);return node;}
 Document.prototype.deepElementFromPoint=function(x,y)
 {var node=this.elementFromPoint(x,y);while(node&&node.shadowRoot)
 node=node.shadowRoot.elementFromPoint(x,y);return node;}
-function isEnterKey(event){return event.keyCode!==229&&event.keyIdentifier==="Enter";}
+function isEnterKey(event)
+{return event.keyCode!==229&&event.keyIdentifier==="Enter";}
+function isEscKey(event)
+{return event.keyCode===27;}
 function consumeEvent(e)
-{e.consume();};WebInspector={};WebInspector.addExtensions=function(){};(function()
+{e.consume();}
+function runOnWindowLoad(callback)
+{function windowLoaded()
+{window.removeEventListener("DOMContentLoaded",windowLoaded,false);callback();}
+if(document.readyState==="complete"||document.readyState==="interactive")
+callback();else
+window.addEventListener("DOMContentLoaded",windowLoaded,false);};(function()
 {function toolboxLoaded()
 {if(!window.opener)
-return;window.opener.WebInspector["app"]["toolboxLoaded"](document);}
-function windowLoaded()
-{window.removeEventListener("DOMContentLoaded",windowLoaded,false);toolboxLoaded();}
-function initToolbox()
-{if(document.readyState==="complete")
-toolboxLoaded();else
-window.addEventListener("DOMContentLoaded",windowLoaded,false);}
-initToolbox();})();;applicationDescriptor=[{"type":"autostart","name":"platform"},{"type":"autostart","name":"toolbox_bootstrap"}];Runtime.startApplication("toolbox");
\ No newline at end of file
+return;var app=window.opener.WebInspector["AdvancedApp"]["_instance"]();app["toolboxLoaded"](document);}
+runOnWindowLoad(toolboxLoaded);})();;applicationDescriptor=[{"type":"autostart","name":"platform"},{"type":"autostart","name":"toolbox_bootstrap"}];Runtime.startApplication("toolbox");
\ No newline at end of file
